==> kubernetes-model-core-4.13.3-sources.jar: io/fabric8/kubernetes/api/model/ExecConfigBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ExecConfigBuilder extends ExecConfigFluentImpl<ExecConfigBuilder> implements VisitableBuilder<ExecConfig,ExecConfigBuilder> {

    ExecConfigFluent<?> fluent;
    Boolean validationEnabled;

    public ExecConfigBuilder() { 
        this(true);
    }


    public ExecConfigBuilder(Boolean validationEnabled) { 
        this(new ExecConfig(), validationEnabled);
    }


    public ExecConfigBuilder(ExecConfigFluent<?> fluent) { 
        this(fluent, true);
    }


    public ExecConfigBuilder(ExecConfigFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ExecConfig(), validationEnabled);
    }


    public ExecConfigBuilder(ExecConfigFluent<?> fluent,ExecConfig instance) { 
        this(fluent, instance, true);
    }


    public ExecConfigBuilder(ExecConfigFluent<?> fluent,ExecConfig instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withArgs(instance.getArgs()); 
        fluent.withCommand(instance.getCommand()); 
        fluent.withEnv(instance.getEnv()); 
        fluent.withInstallHint(instance.getInstallHint()); 
        this.validationEnabled = validationEnabled; 
    }


    public ExecConfigBuilder(ExecConfig instance) { 
        this(instance,true);
    }


    public ExecConfigBuilder(ExecConfig instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withArgs(instance.getArgs()); 
        this.withCommand(instance.getCommand()); 
        this.withEnv(instance.getEnv()); 
        this.withInstallHint(instance.getInstallHint()); 
        this.validationEnabled = validationEnabled; 
    }


    public ExecConfig build() {
        ExecConfig buildable = new ExecConfig(fluent.getApiVersion(),fluent.getArgs(),fluent.getCommand(),fluent.getEnv(),fluent.getInstallHint());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ExecConfigBuilder that = (ExecConfigBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.1.0-sources.jar: io/fabric8/kubernetes/api/model/ExecConfigBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ExecConfigBuilder extends ExecConfigFluentImpl<ExecConfigBuilder> implements VisitableBuilder<ExecConfig,ExecConfigBuilder> {

    ExecConfigFluent<?> fluent;
    Boolean validationEnabled;

    public ExecConfigBuilder() {
        this(true);
    }

    public ExecConfigBuilder(Boolean validationEnabled) {
        this(new ExecConfig(), validationEnabled);
    }

    public ExecConfigBuilder(ExecConfigFluent<?> fluent) {
        this(fluent, true);
    }

    public ExecConfigBuilder(ExecConfigFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ExecConfig(), validationEnabled);
    }

    public ExecConfigBuilder(ExecConfigFluent<?> fluent,ExecConfig instance) {
        this(fluent, instance, true);
    }

    public ExecConfigBuilder(ExecConfigFluent<?> fluent,ExecConfig instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withArgs(instance.getArgs()); 
        fluent.withCommand(instance.getCommand()); 
        fluent.withEnv(instance.getEnv()); 
        fluent.withInstallHint(instance.getInstallHint()); 
        fluent.withProvideClusterInfo(instance.getProvideClusterInfo()); 
        this.validationEnabled = validationEnabled; 
    }

    public ExecConfigBuilder(ExecConfig instance) {
        this(instance,true);
    }

    public ExecConfigBuilder(ExecConfig instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withArgs(instance.getArgs()); 
        this.withCommand(instance.getCommand()); 
        this.withEnv(instance.getEnv()); 
        this.withInstallHint(instance.getInstallHint()); 
        this.withProvideClusterInfo(instance.getProvideClusterInfo()); 
        this.validationEnabled = validationEnabled; 
    }

    public ExecConfig build() {
        ExecConfig buildable = new ExecConfig(fluent.getApiVersion(),fluent.getArgs(),fluent.getCommand(),fluent.getEnv(),fluent.getInstallHint(),fluent.isProvideClusterInfo());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ExecConfigBuilder that = (ExecConfigBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
